"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePositionChanges = usePositionChanges;

var _react = require("react");

var _operators = require("rxjs/operators");

var _visualAnalyticsComponents = require("visual-analytics-components");

var _interfaces = require("../../interfaces");

var _types = require("../../types");

var _tables = require("./tables");

function usePositionChanges(api, config, manager) {
  var vertexTable = (0, _tables.useVertexTable)(manager);
  (0, _react.useEffect)(function () {
    if (api) {
      var subscription = manager.messages.pipe((0, _operators.filter)(isPositionChange(config)), (0, _operators.throttleTime)(50, undefined, {
        trailing: true
      })).subscribe(function () {
        var newPositions = {};
        var slice = vertexTable.slice(_visualAnalyticsComponents.SliceType.All);

        for (var i = 0; i < slice.length(); ++i) {
          var row = slice.get(i);
          newPositions[row.id] = {
            x: row.x,
            y: row.y,
            z: row.z
          };
        }

        api.changePositions(newPositions);
      });
      return function () {
        return subscription.unsubscribe();
      };
    }
  }, [api, config, manager, vertexTable]);
}

var isPositionChange = function isPositionChange(config) {
  return function (evt) {
    return evt.type === _types.GraphMessageType.PositionsChanged && evt.payload.instanceId === (config.instanceId || _interfaces.DEFAULT_INSTANCE_ID);
  };
};