function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
import { Axes, GraphView, HighlightHoveredNode, LabelHoveredNode, HandleNodeClicks, Nodes, Edges, NodeSetHighlight, NodeSetLabel, Camera } from '@graspologic/react';
import { SettingsPane, DisplaySettings, EdgeSettings, NodeSettings } from '@graspologic/render-controls-react';
import * as React from 'react';
import { memo, useMemo, useState, useEffect, useCallback } from 'react';
import useResizeObserver from 'use-resize-observer'; // import { LayoutSettings } from '@graspologic/layout-react'

import { DEFAULT_INSTANCE_ID, COMPONENT_ID } from '../interfaces';
import { GlobalStyles } from './GlobalStyles';
import { useColorizer } from './hooks/useColorizer';
import { useGraphData } from './hooks/useGraphData';
import { useHoverHandler } from './hooks/useHoverHandler';
import { usePositionChanges } from './hooks/usePositionChanges';
import { useVertexClickHandler } from './hooks/useVertexClickHandler';
import { useHighlightedVertices, useSelectedVertices } from './hooks/vac';
var styles = {
  brickWall: {
    height: '100%',
    width: '100%'
  }
};
export var Graph = memo(function GraphComponentInner(_ref) {
  var manager = _ref.manager,
      configuration = _ref.configuration;
  var showControls = configuration.showControls != null ? configuration.showControls : true;
  var renderSettings = useMemo(function () {
    return configuration.rendering || {};
  }, [configuration]);
  var controlsSettings = useMemo(function () {
    return configuration.controls || {};
  }, [configuration]);

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      api = _useState2[0],
      setApi = _useState2[1];

  var is3D = Boolean(renderSettings.is3D);
  var colorizer = useColorizer(manager, configuration);
  var graphData = useGraphData(manager, is3D);
  var handleVertexClick = useVertexClickHandler(manager);
  var highlighted = useHighlightedVertices(manager);
  var selected = useSelectedVertices(manager);
  var onHover = useHoverHandler(manager);

  var _useResizeObserver = useResizeObserver(),
      ref = _useResizeObserver.ref;

  usePositionChanges(api, configuration, manager);
  var instanceId = configuration.instanceId || DEFAULT_INSTANCE_ID;
  var renderConfig = api === null || api === void 0 ? void 0 : api.config;
  useEffect(function () {
    if (renderConfig) {
      // Load any existing config at startup
      var existingState = manager.getState(COMPONENT_ID, instanceId);

      if (existingState) {
        renderConfig.load(existingState);
      } // Set up a subscription


      var subscription = renderConfig.onChange.subscribe(function () {
        manager.setState(COMPONENT_ID, instanceId, renderConfig.copy());
      });
      return function () {
        return subscription.unsubscribe();
      };
    }
  }, [renderConfig, instanceId, manager]);
  return React.createElement(React.Fragment, null, React.createElement(GlobalStyles, null), React.createElement("div", {
    style: styles.brickWall,
    ref: ref
  }, React.createElement(GraphView, {
    colorizer: colorizer,
    data: graphData,
    backgroundColor: [0, 0, 0, 0],
    is3D: is3D,
    ref: useCallback(function (ref) {
      if (ref !== api) {
        setApi(ref);
      }
    }, [api]),
    style: styles.brickWall
  }, React.createElement(Axes, {
    inCorner: renderSettings.cornerAxes,
    shown: renderSettings.drawAxes
  }), React.createElement(Camera, {
    interactive: true
  }), React.createElement(HandleNodeClicks, {
    onClick: handleVertexClick
  }), React.createElement(HighlightHoveredNode, {
    onHover: onHover
  }), React.createElement(LabelHoveredNode, null), React.createElement(NodeSetHighlight, {
    vertexIds: highlighted
  }), React.createElement(NodeSetLabel, {
    vertexIds: highlighted
  }), React.createElement(NodeSetHighlight, {
    vertexIds: selected
  }), React.createElement(NodeSetLabel, {
    vertexIds: selected
  }), React.createElement(Nodes, {
    shown: renderSettings.drawNodes,
    minRadius: renderSettings.nodeMinRadius,
    maxRadius: renderSettings.nodeMaxRadius,
    outline: renderSettings.nodeOutline,
    hideOnMove: renderSettings.hideNodesOnMove
  }), React.createElement(Edges, {
    shown: renderSettings.drawEdges,
    alpha: renderSettings.edgeAlpha,
    minWidth: renderSettings.edgeMinWidth,
    maxWidth: renderSettings.edgeMaxWidth,
    hideOnMove: renderSettings.hideNodesOnMove,
    depthWrite: renderSettings.edgeDepthWrite,
    antialias: renderSettings.edgeAntialias,
    constantWidth: renderSettings.constantEdgeWidth
  }), showControls ? React.createElement(SettingsPane, null, React.createElement(DisplaySettings, {
    interpolationTimeRange: controlsSettings.displayInterpolationTimeRange
  }), React.createElement(NodeSettings, {
    minRadiusRange: controlsSettings.nodeMinRadiusRange,
    maxRadiusRange: controlsSettings.nodeMaxRadiusRange
  }), React.createElement(EdgeSettings, {
    alphaRange: controlsSettings.edgeAlphaRange,
    minWidthRange: controlsSettings.edgeMinWidthRange,
    maxWidthRange: controlsSettings.edgeMaxWidthRange
  })) : null)));
});