import { useEffect } from 'react';
import { filter, throttleTime } from 'rxjs/operators';
import { SliceType } from 'visual-analytics-components';
import { DEFAULT_INSTANCE_ID } from '../../interfaces';
import { GraphMessageType } from '../../types';
import { useVertexTable } from './tables';
export function usePositionChanges(api, config, manager) {
  var vertexTable = useVertexTable(manager);
  useEffect(function () {
    if (api) {
      var subscription = manager.messages.pipe(filter(isPositionChange(config)), throttleTime(50, undefined, {
        trailing: true
      })).subscribe(function () {
        var newPositions = {};
        var slice = vertexTable.slice(SliceType.All);

        for (var i = 0; i < slice.length(); ++i) {
          var row = slice.get(i);
          newPositions[row.id] = {
            x: row.x,
            y: row.y,
            z: row.z
          };
        }

        api.changePositions(newPositions);
      });
      return function () {
        return subscription.unsubscribe();
      };
    }
  }, [api, config, manager, vertexTable]);
}

var isPositionChange = function isPositionChange(config) {
  return function (evt) {
    return evt.type === GraphMessageType.PositionsChanged && evt.payload.instanceId === (config.instanceId || DEFAULT_INSTANCE_ID);
  };
};