function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
import { useState, useEffect } from 'react';
import { filter, throttleTime } from 'rxjs/operators';
import { SliceType, MessageTypes } from 'visual-analytics-components';
import { useSlice } from './useSlice';
export function useHighlightedVertices(manager) {
  var vertices = useSlice(manager, SliceType.Highlighted);

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      ids = _useState2[0],
      setIds = _useState2[1];

  useEffect(function () {
    if (vertices) {
      manager.messages.pipe(filter(isHighlightChangeEvent), throttleTime(50, undefined, {
        trailing: true
      })).subscribe(function () {
        setIds(readSlice(vertices));
      });
    }
  }, [manager, vertices]);
  return ids;
}
export function useSelectedVertices(manager) {
  var vertices = useSlice(manager, SliceType.Selected);

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      ids = _useState4[0],
      setIds = _useState4[1];

  useEffect(function () {
    if (vertices) {
      manager.messages.pipe(filter(isSelectionChangeEvent), throttleTime(50, undefined, {
        trailing: true
      })).subscribe(function () {
        setIds(readSlice(vertices));
      });
    }
  }, [manager, vertices]);
  return ids;
}

function readSlice(slice) {
  var result = [];

  for (var i = 0; i < slice.length(); ++i) {
    result.push(slice.get(i).id);
  }

  return result;
}

var isHighlightChangeEvent = function isHighlightChangeEvent(evt) {
  return evt.type === MessageTypes.Data.Changed && evt.payload.table === 'vertices' && evt.payload.slice === SliceType.Highlighted;
};

var isSelectionChangeEvent = function isSelectionChangeEvent(evt) {
  return evt.type === MessageTypes.Data.Changed && evt.payload.table === 'vertices' && evt.payload.slice === SliceType.Selected;
};