/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
import { GraphContainer } from '@graspologic/graph';
import debug from 'debug';
import { SliceType } from 'visual-analytics-components';
import { isLayoutRequired } from './isLayoutRequired';
const log = debug('vac:graph');
/**
 * A scale applied to the dataset
 */
export function readDataset(data, is3D) {
    const nodesTable = data.table('vertices');
    const edgesTable = data.table('edges');
    const allNodes = nodesTable.slice(SliceType.All);
    const allEdges = edgesTable.slice(SliceType.All);
    const nodes = [];
    const edges = [];
    let rv;
    for (const node of allNodes) {
        rv = node;
        if (rv) {
            nodes.push({
                // Make a copy so we don't mutate
                ...rv,
                z: rv.z ? rv.z : 0,
            });
        }
    }
    for (const edge of allEdges) {
        if (edge) {
            edges.push(edge);
        }
    }
    const input = { nodes, edges };
    const randomize = isLayoutRequired(input)
        ? [-500, 500, -500, 500]
        : undefined;
    if (randomize) {
        log('randomizing node positions');
    }
    return GraphContainer.intern(input, { randomize });
}
