import { useEffect } from 'react';
import { filter, throttleTime } from 'rxjs/operators';
import { SliceType } from 'visual-analytics-components';
import { DEFAULT_INSTANCE_ID } from '../../interfaces';
import { GraphMessageType } from '../../types';
import { useVertexTable } from './tables';
export function usePositionChanges(api, config, manager) {
    const vertexTable = useVertexTable(manager);
    useEffect(() => {
        if (api) {
            const subscription = manager.messages
                .pipe(filter(isPositionChange(config)), throttleTime(50, undefined, { trailing: true }))
                .subscribe(() => {
                const newPositions = {};
                const slice = vertexTable.slice(SliceType.All);
                for (let i = 0; i < slice.length(); ++i) {
                    const row = slice.get(i);
                    newPositions[row.id] = { x: row.x, y: row.y, z: row.z };
                }
                api.changePositions(newPositions);
            });
            return () => subscription.unsubscribe();
        }
    }, [api, config, manager, vertexTable]);
}
const isPositionChange = (config) => (evt) => evt.type === GraphMessageType.PositionsChanged &&
    evt.payload.instanceId === (config.instanceId || DEFAULT_INSTANCE_ID);
