/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
import { useState, useEffect } from 'react';
import { filter, throttleTime } from 'rxjs/operators';
import { SliceType, MessageTypes, } from 'visual-analytics-components';
import { useSlice } from './useSlice';
export function useHighlightedVertices(manager) {
    const vertices = useSlice(manager, SliceType.Highlighted);
    const [ids, setIds] = useState([]);
    useEffect(() => {
        if (vertices) {
            manager.messages
                .pipe(filter(isHighlightChangeEvent), throttleTime(50, undefined, { trailing: true }))
                .subscribe(() => {
                setIds(readSlice(vertices));
            });
        }
    }, [manager, vertices]);
    return ids;
}
export function useSelectedVertices(manager) {
    const vertices = useSlice(manager, SliceType.Selected);
    const [ids, setIds] = useState([]);
    useEffect(() => {
        if (vertices) {
            manager.messages
                .pipe(filter(isSelectionChangeEvent), throttleTime(50, undefined, { trailing: true }))
                .subscribe(() => {
                setIds(readSlice(vertices));
            });
        }
    }, [manager, vertices]);
    return ids;
}
function readSlice(slice) {
    const result = [];
    for (let i = 0; i < slice.length(); ++i) {
        result.push(slice.get(i).id);
    }
    return result;
}
const isHighlightChangeEvent = (evt) => evt.type === MessageTypes.Data.Changed &&
    evt.payload.table === 'vertices' &&
    evt.payload.slice === SliceType.Highlighted;
const isSelectionChangeEvent = (evt) => evt.type === MessageTypes.Data.Changed &&
    evt.payload.table === 'vertices' &&
    evt.payload.slice === SliceType.Selected;
